development_QA.rst

# Questions under development

# 1. How should gui.set() work?

17. When gui.set() is called, should all widget value be initialized with defaults before setting with argument?

1. Yes.

# 2. How should gui.clear() work?

17. Does gui.clear() 'erase contents of widgets' or 'fill with default value?'

1. 'fill with default value' looks better. From Q1, clear() is almost same as set({})

# 3. How should gui.get() work?

17. Does gui.get() starts at 'd={} (NULL member)' or 'd=default_value'?

1. ...